==> jc-1.4.0.tar.gz: polyglot/ast/Binary__24Operator.c <==
// public class polyglot.ast.Binary$Operator

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class fb819a4019abba3a polyglot_ast_Binary
// @dep_class f7a7478dc07f2986 polyglot_ast_Binary__24Operator
// @dep_class 6f4f5f315efa9fd7 polyglot_ast_Precedence
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_ast_Binary
// @dep_header polyglot_ast_Binary__24Operator
// @dep_header polyglot_ast_Precedence

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/ast/Binary.h"
#include "polyglot/ast/Binary__24Operator.h"
#include "polyglot/ast/Precedence.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// polyglot.ast.Precedence prec
static _jc_field _jc_polyglot_ast_Binary__24Operator$field_info$prec = {
	.name=		"prec",
	.signature=	"Lpolyglot/ast/Precedence;",
	.class=		&_jc_polyglot_ast_Binary__24Operator$type,
	.type=		&_jc_polyglot_ast_Precedence$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_ast_Binary__24Operator$object, refs[-1].polyglot_ast_Binary__24Operator.prec),
};

// Fields
static _jc_field *const _jc_polyglot_ast_Binary__24Operator$fields[] = {
	&_jc_polyglot_ast_Binary__24Operator$field_info$prec
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, polyglot.ast.Precedence)
//

static _jc_linenum _jc_polyglot_ast_Binary__24Operator$linenum_table$_init$b50c1c41279523d3[];

static const unsigned char _jc_polyglot_ast_Binary__24Operator$param_ptypes$_init$b50c1c41279523d3[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_ast_Binary__24Operator$param_types$_init$b50c1c41279523d3[] = {
	&_jc_java_lang_String$type,
	&_jc_polyglot_ast_Precedence$type
};

_jc_method _jc_polyglot_ast_Binary__24Operator$method_info$_init$b50c1c41279523d3 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Lpolyglot/ast/Precedence;)V",
	.class=			&_jc_polyglot_ast_Binary__24Operator$type,
	.param_types=		&_jc_polyglot_ast_Binary__24Operator$param_types$_init$b50c1c41279523d3,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ast_Binary__24Operator$param_ptypes$_init$b50c1c41279523d3,
	.signature_hash=	_JC_JLONG(0xb50c1c41279523d3),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ast_Binary__24Operator$method$_init$b50c1c41279523d3,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_polyglot_ast_Binary__24Operator$linenum_table$_init$b50c1c41279523d3
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ast_Binary__24Operator, _init$b50c1c41279523d3);

void
_jc_polyglot_ast_Binary__24Operator$method$_init$b50c1c41279523d3(_jc_env *const env, _jc_polyglot_ast_Binary__24Operator$object *this, _jc_java_lang_String$object *param0, _jc_polyglot_ast_Precedence$object *param1)
{
	struct _jc_polyglot_ast_Binary__24Operator$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_polyglot_ast_Precedence$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(16);				// 0
	_JC_INVOKE_NONVIRTUAL(env, polyglot_util_Enum, _init$c31b894660454d13, 0, r0, r1);
	_JC_LINE_NUMBER(17);				// 1
	_JC_REF_FIELD(env, r0, polyglot_ast_Binary__24Operator, prec) = r2;
	_JC_LINE_NUMBER(18);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public polyglot.ast.Precedence precedence()
//

static _jc_linenum _jc_polyglot_ast_Binary__24Operator$linenum_table$precedence$334b0140c8dd854d[];

static const unsigned char _jc_polyglot_ast_Binary__24Operator$param_ptypes$precedence$334b0140c8dd854d[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_ast_Binary__24Operator$method_info$precedence$334b0140c8dd854d = {
	.name=			"precedence",
	.signature=		"()Lpolyglot/ast/Precedence;",
	.class=			&_jc_polyglot_ast_Binary__24Operator$type,
	.return_type=		&_jc_polyglot_ast_Precedence$type,
	.param_ptypes=		&_jc_polyglot_ast_Binary__24Operator$param_ptypes$precedence$334b0140c8dd854d,
	.signature_hash=	_JC_JLONG(0x334b0140c8dd854d),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ast_Binary__24Operator$vtable, polyglot_ast_Binary__24Operator.precedence$334b0140c8dd854d) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ast_Binary__24Operator$linenum_table$precedence$334b0140c8dd854d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ast_Binary__24Operator, precedence$334b0140c8dd854d);

_jc_polyglot_ast_Precedence$object *
_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d(_jc_env *const env, _jc_polyglot_ast_Binary__24Operator$object *this)
{
	struct _jc_polyglot_ast_Binary__24Operator$object *r0;
	struct _jc_polyglot_ast_Precedence$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(21);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_ast_Binary__24Operator, prec);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_ast_Binary__24Operator$methods[] = {
	&_jc_polyglot_ast_Binary__24Operator$method_info$_init$b50c1c41279523d3,
	&_jc_polyglot_ast_Binary__24Operator$method_info$precedence$334b0140c8dd854d
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_6[] = {
	&_jc_polyglot_ast_Binary__24Operator$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_39[] = {
	&_jc_polyglot_util_Enum$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[6]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_6,
	[39]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_39,
	[65]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_65,
	[113]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_ast_Binary__24Operator$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "polyglot/ast/Binary",	_JC_JLONG(0xfb819a4019abba3a) },
	{ "polyglot/ast/Precedence",	_JC_JLONG(0x6f4f5f315efa9fd7) },
	{ "polyglot/util/Enum",	_JC_JLONG(0x82f09079602e8c27) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_ast_Binary__24Operator$vtype _jc_polyglot_ast_Binary__24Operator$type = {
    .type= {
	.name=			"polyglot/ast/Binary$Operator",
	.superclass=		&_jc_polyglot_util_Enum$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		15,
		.hash=			_JC_JLONG(0xf7a7478dc07f2986),
		.source_file=		"Binary.java",
		.instance_size=		sizeof(_jc_polyglot_ast_Binary__24Operator$refs) + sizeof(_jc_polyglot_ast_Binary__24Operator$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_polyglot_ast_Binary__24Operator$fields) / sizeof(*_jc_polyglot_ast_Binary__24Operator$fields),
		.fields=		_jc_polyglot_ast_Binary__24Operator$fields,
		.num_methods=		sizeof(_jc_polyglot_ast_Binary__24Operator$methods) / sizeof(*_jc_polyglot_ast_Binary__24Operator$methods),
		.methods=		_jc_polyglot_ast_Binary__24Operator$methods,
		.instanceof_hash_table=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_table,
		.outer_class=		&_jc_polyglot_ast_Binary$type,
		.num_class_depends=		sizeof(_jc_polyglot_ast_Binary__24Operator$class_depends) / sizeof(*_jc_polyglot_ast_Binary__24Operator$class_depends),
		.class_depends=		_jc_polyglot_ast_Binary__24Operator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_polyglot_util_Enum$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_util_Enum$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_util_Enum= {
	    .equals$8a15e0625571c581=
		&_jc_polyglot_util_Enum$method$equals$8a15e0625571c581,
	    .intern$50b920faa861ae4f=
		&_jc_polyglot_util_Enum$method$intern$50b920faa861ae4f,
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_util_Enum$method$toString$7ea43b33b80a3070,
	},
	.polyglot_ast_Binary__24Operator= {
	    .precedence$334b0140c8dd854d=
		&_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/ast/Binary__24Operator.c <==
// public class polyglot.ast.Binary$Operator

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class fb819a4019abba3a polyglot_ast_Binary
// @dep_class f7a7478dc07f2986 polyglot_ast_Binary__24Operator
// @dep_class 6f4f5f315efa9fd7 polyglot_ast_Precedence
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_ast_Binary
// @dep_header polyglot_ast_Binary__24Operator
// @dep_header polyglot_ast_Precedence

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/ast/Binary.h"
#include "polyglot/ast/Binary__24Operator.h"
#include "polyglot/ast/Precedence.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// polyglot.ast.Precedence prec
static _jc_field _jc_polyglot_ast_Binary__24Operator$field_info$prec = {
	.name=		"prec",
	.signature=	"Lpolyglot/ast/Precedence;",
	.class=		&_jc_polyglot_ast_Binary__24Operator$type,
	.type=		&_jc_polyglot_ast_Precedence$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_ast_Binary__24Operator$object, refs[-1].polyglot_ast_Binary__24Operator.prec),
};

// Fields
static _jc_field *const _jc_polyglot_ast_Binary__24Operator$fields[] = {
	&_jc_polyglot_ast_Binary__24Operator$field_info$prec
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, polyglot.ast.Precedence)
//

static _jc_linenum _jc_polyglot_ast_Binary__24Operator$linenum_table$_init$b50c1c41279523d3[];

static const unsigned char _jc_polyglot_ast_Binary__24Operator$param_ptypes$_init$b50c1c41279523d3[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_ast_Binary__24Operator$param_types$_init$b50c1c41279523d3[] = {
	&_jc_java_lang_String$type,
	&_jc_polyglot_ast_Precedence$type
};

_jc_method _jc_polyglot_ast_Binary__24Operator$method_info$_init$b50c1c41279523d3 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Lpolyglot/ast/Precedence;)V",
	.class=			&_jc_polyglot_ast_Binary__24Operator$type,
	.param_types=		&_jc_polyglot_ast_Binary__24Operator$param_types$_init$b50c1c41279523d3,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ast_Binary__24Operator$param_ptypes$_init$b50c1c41279523d3,
	.signature_hash=	_JC_JLONG(0xb50c1c41279523d3),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ast_Binary__24Operator$method$_init$b50c1c41279523d3,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_polyglot_ast_Binary__24Operator$linenum_table$_init$b50c1c41279523d3
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ast_Binary__24Operator, _init$b50c1c41279523d3);

void _JC_JCNI_ATTR
_jc_polyglot_ast_Binary__24Operator$method$_init$b50c1c41279523d3(_jc_env *const env, _jc_polyglot_ast_Binary__24Operator$object *this, _jc_java_lang_String$object *param0, _jc_polyglot_ast_Precedence$object *param1)
{
	struct _jc_polyglot_ast_Binary__24Operator$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_polyglot_ast_Precedence$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(16);				// 0
	_JC_INVOKE_NONVIRTUAL(env, polyglot_util_Enum, _init$c31b894660454d13, 0, r0, r1);
	_JC_LINE_NUMBER(17);				// 1
	_JC_REF_FIELD(env, r0, polyglot_ast_Binary__24Operator, prec) = r2;
	_JC_LINE_NUMBER(18);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public polyglot.ast.Precedence precedence()
//

static _jc_linenum _jc_polyglot_ast_Binary__24Operator$linenum_table$precedence$334b0140c8dd854d[];

static const unsigned char _jc_polyglot_ast_Binary__24Operator$param_ptypes$precedence$334b0140c8dd854d[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_ast_Binary__24Operator$method_info$precedence$334b0140c8dd854d = {
	.name=			"precedence",
	.signature=		"()Lpolyglot/ast/Precedence;",
	.class=			&_jc_polyglot_ast_Binary__24Operator$type,
	.return_type=		&_jc_polyglot_ast_Precedence$type,
	.param_ptypes=		&_jc_polyglot_ast_Binary__24Operator$param_ptypes$precedence$334b0140c8dd854d,
	.signature_hash=	_JC_JLONG(0x334b0140c8dd854d),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_ast_Binary__24Operator$vtable, polyglot_ast_Binary__24Operator.precedence$334b0140c8dd854d) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ast_Binary__24Operator$linenum_table$precedence$334b0140c8dd854d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ast_Binary__24Operator, precedence$334b0140c8dd854d);

_jc_polyglot_ast_Precedence$object * _JC_JCNI_ATTR
_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d(_jc_env *const env, _jc_polyglot_ast_Binary__24Operator$object *this)
{
	struct _jc_polyglot_ast_Binary__24Operator$object *r0;
	struct _jc_polyglot_ast_Precedence$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(21);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_ast_Binary__24Operator, prec);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_ast_Binary__24Operator$methods[] = {
	&_jc_polyglot_ast_Binary__24Operator$method_info$_init$b50c1c41279523d3,
	&_jc_polyglot_ast_Binary__24Operator$method_info$precedence$334b0140c8dd854d
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_6[] = {
	&_jc_polyglot_ast_Binary__24Operator$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_39[] = {
	&_jc_polyglot_util_Enum$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_ast_Binary__24Operator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[6]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_6,
	[39]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_39,
	[65]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_65,
	[101]=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_ast_Binary__24Operator$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "polyglot/ast/Binary",	_JC_JLONG(0xfb819a4019abba3a) },
	{ "polyglot/ast/Precedence",	_JC_JLONG(0x6f4f5f315efa9fd7) },
	{ "polyglot/util/Enum",	_JC_JLONG(0x82f09079602e8c27) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_ast_Binary__24Operator$vtype _jc_polyglot_ast_Binary__24Operator$type = {
    .type= {
	.name=			"polyglot/ast/Binary$Operator",
	.superclass=		&_jc_polyglot_util_Enum$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		15,
		.hash=			_JC_JLONG(0xf7a7478dc07f2986),
		.source_file=		"Binary.java",
		.instance_size=		sizeof(_jc_polyglot_ast_Binary__24Operator$refs) + sizeof(_jc_polyglot_ast_Binary__24Operator$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_polyglot_ast_Binary__24Operator$fields) / sizeof(*_jc_polyglot_ast_Binary__24Operator$fields),
		.fields=		_jc_polyglot_ast_Binary__24Operator$fields,
		.num_methods=		sizeof(_jc_polyglot_ast_Binary__24Operator$methods) / sizeof(*_jc_polyglot_ast_Binary__24Operator$methods),
		.methods=		_jc_polyglot_ast_Binary__24Operator$methods,
		.instanceof_hash_table=	_jc_polyglot_ast_Binary__24Operator$instanceof_hash_table,
		.outer_class=		&_jc_polyglot_ast_Binary$type,
		.num_class_depends=		sizeof(_jc_polyglot_ast_Binary__24Operator$class_depends) / sizeof(*_jc_polyglot_ast_Binary__24Operator$class_depends),
		.class_depends=		_jc_polyglot_ast_Binary__24Operator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_polyglot_util_Enum$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_polyglot_util_Enum$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_util_Enum= {
	    .equals$8a15e0625571c581=
		&_jc_polyglot_util_Enum$method$equals$8a15e0625571c581,
	    .intern$50b920faa861ae4f=
		&_jc_polyglot_util_Enum$method$intern$50b920faa861ae4f,
	    .toString$7ea43b33b80a3070=
		&_jc_polyglot_util_Enum$method$toString$7ea43b33b80a3070,
	},
	.polyglot_ast_Binary__24Operator= {
	    .precedence$334b0140c8dd854d=
		&_jc_polyglot_ast_Binary__24Operator$method$precedence$334b0140c8dd854d,
	},
    }
};
